﻿using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Input;

namespace Ideia
{
    class Input
    {
        KeyboardState lastKeyboardState;
        KeyboardState newKeyboardState;

        MouseState lastMouseState;
        MouseState newMouseState;

        Controller controller;
        public Controller Controller { get { return controller; } }

        public Input()
        {
            lastKeyboardState = new KeyboardState();
            newKeyboardState = new KeyboardState();
            lastMouseState = new MouseState();
            newMouseState = new MouseState();
            controller = new Controller();
        }

        public void Update(KeyboardState keyboardState, MouseState mouseState, GamePadState gamePadState)
        {
            lastKeyboardState = newKeyboardState;
            newKeyboardState = keyboardState;

            lastMouseState = newMouseState;
            newMouseState = mouseState;

            controller.Update(gamePadState);
        }

        public bool IsPressed(Keys key)
        {
            return newKeyboardState.IsKeyDown(key);
        }

        public bool IsNewPress(Keys key)
        {
            return ((newKeyboardState.IsKeyDown(key)) && (lastKeyboardState.IsKeyUp(key)));
        }

        public int MouseScrool()
        {
            return (newMouseState.ScrollWheelValue - lastMouseState.ScrollWheelValue);
        }

        public Vector2 MouseXYPosition()
        {
            return new Vector2((newMouseState.X), (newMouseState.Y));
        }

        public Vector2 MouseXYChanged()
        {
            return new Vector2((newMouseState.X - lastMouseState.X), (newMouseState.Y - lastMouseState.Y));
        }

        public bool MouseRightButtonIsPressed()
        {
            return (newMouseState.RightButton == ButtonState.Pressed);
        }

        public bool MouseRightButtonIsNewPress()
        {
            return (newMouseState.RightButton == ButtonState.Pressed) && (lastMouseState.RightButton == ButtonState.Released);
        }

        public bool MouseLeftButtonIsPressed()
        {
            return (newMouseState.LeftButton == ButtonState.Pressed);
        }

        public bool MouseLeftButtonIsNewPress()
        {
            return (newMouseState.LeftButton == ButtonState.Pressed) && (lastMouseState.LeftButton == ButtonState.Released);
        }
    }
}
